@@ -56,8 +56,6 @@ class Pact:
 
         @staticmethod
         def sign(msg, keypair):
-            print("from sign")
-            print(msg)
             hs_bin = Pact.Crypto.hash_bin(msg)
             hsh = Pact.Crypto.b64_url_encoded_hash(hs_bin)
             sig_bin = signing.SigningKey(seed=keypair['secretKey'],
@@ -66,8 +64,6 @@ class Pact:
 
         @staticmethod
         def sign_map(msg, kp):
-            print("from signmap")
-            print(msg)
             hs_bin = Pact.Crypto.hash_bin(msg)
             hsh = Pact.Crypto.b64_url_encoded_hash(hs_bin)
             if "publicKey" in kp.keys() and "secretKey" in kp.keys():
@@ -77,8 +73,6 @@ class Pact:
 
         @staticmethod
         def attach_sig(msg, kp_array):
-            print("from attachsig")
-            print(msg)
             hs_bin = Pact.Crypto.hash_bin(msg)
             hsh = Pact.Crypto.b64_url_encoded_hash(hs_bin)
             if len(kp_array) == 0:
@@ -153,6 +147,7 @@ class Pact:
             sigs = Pact.Crypto.attach_sig(cmd, kp_array)
             return Pact.Api.mk_single_cmd(sigs, cmd)
 
+        @staticmethod
         def mk_public_send(cmds):
             return {"cmds": utils.as_list(cmds)}
 
@@ -175,11 +170,12 @@ class Pact:
         @staticmethod
         def mk_exp(module_and_function, namespace=None, **kwargs):
             if namespace:
-                string = "("+namespace+"."+module_and_function+" "
+                string = "("+namespace+"."+module_and_function
             else:
                 string = "("+module_and_function+" "
             for key, value in kwargs.items():
-                string += json.dumps(value)
+                string += " " + value if str(value).startswith('(') or str(value).startswith('[') \
+                    else " " + json.dumps(value)
             return string+")"
 
     class Simple:
@@ -293,22 +289,25 @@ class Pact:
                                                      cmd['nonce'], cmd['keyPairs'])
 
         @staticmethod
-        def fetch_send_raw(send_cmd, api_host):
+        def fetch_send_raw(send_cmd, api_host, debug):
             if api_host is None:
                 raise Exception("No apiHost provided")
             send_cmds = list(map(Pact.Fetch.make_prepare_cmd, utils.as_list(send_cmd)))
-            return rt.post(api_host + '/api/v1/send', json=Pact.Api.mk_public_send(send_cmds), headers=utils.get_headers(), timeout=10)
+            if debug:
+                print(send_cmds)
+            return rt.post(api_host + '/api/v1/send', json=Pact.Api.mk_public_send(send_cmds), headers=utils.get_headers())
 
         @staticmethod
-        def send(send_cmd, api_host):
-            res = Pact.Fetch.fetch_send_raw(send_cmd, api_host)
+        def send(send_cmd, api_host, debug=False):
+
+            res = Pact.Fetch.fetch_send_raw(send_cmd, api_host, debug)
             return utils.parse_res(res)
 
         @staticmethod
         def fetch_spv_raw(spv_cmd, api_host):
             if api_host is None:
                 raise Exception("No apiHost provided")
-            return rt.post(api_host + '/spv', json=spv_cmd, headers=utils.get_headers(), timeout=10)
+            return rt.post(api_host + '/spv', json=spv_cmd, headers=utils.get_headers())
 
         @staticmethod
         def spv(spv_cmd, api_host):
@@ -324,7 +323,7 @@ class Pact:
                                                            local_cmd['meta'], local_cmd['networkId'],
                                                            local_cmd['nonce'], local_cmd['keyPairs'])
 
-            return rt.post(api_host + '/api/v1/local', json=local_data, headers=utils.get_headers(), timeout=10)
+            return rt.post(api_host + '/api/v1/local', json=local_data, headers=utils.get_headers())
 
         @staticmethod
         def local(local_cmd, api_host):
@@ -335,7 +334,7 @@ class Pact:
         def fetch_poll_raw(poll_cmd, api_host):
             if api_host is None:
                 raise Exception("No apiHost provided")
-            return rt.post(api_host + '/api/v1/poll', json=poll_cmd, headers=utils.get_headers(), timeout=10)
+            return rt.post(api_host + '/api/v1/poll', json=poll_cmd, headers=utils.get_headers())
 
         @staticmethod
         def poll(poll_cmd, api_host):
@@ -346,8 +345,7 @@ class Pact:
         def fetch_listen_raw(listen_cmd, api_host):
             if api_host is None:
                 raise Exception("No apiHost provided")
-            print(listen_cmd)
-            return rt.post(api_host + '/api/v1/listen', json=listen_cmd, headers=utils.get_headers(), timeout=10)
+            return rt.post(api_host + '/api/v1/listen', json=listen_cmd, headers=utils.get_headers())
 
         @staticmethod
         def listen(listen_cmd, api_host):
@@ -357,6 +355,6 @@ class Pact:
         @staticmethod
         def send_signed(signed_cmd, api_host):
             cmd = {"cmds": [signed_cmd]}
-            res = rt.post(api_host + '/api/v1/send', json=cmd, headers=utils.get_headers(), timeout=10)
+            res = rt.post(api_host + '/api/v1/send', json=cmd, headers=utils.get_headers())
             return res.json()
 
